..
  This file describes user-visible changes between the versions.

# Change History

## Development

### 0.0.4

- CI tests with Python versions: 3.7 - 3.11

### 0.0.3

2022-08-08

### 0.0.2

2022-08-08

- CI tests with Python versions: 3.7 - 3.10
- add pyyaml packaging requirement

### 0.0.1

2022-07-26

- Package renamed as `murky` (formerly `condatools`, `boiga`, and `water_moccasin`).
